@@ -1,9 +1,17 @@
 import torch
 import os
-from pdbmender import mend_pdb, prepare_for_addHtaut, add_tautomers, identify_tit_sites, rm_cys_bridges, identify_cter
+from pdbmender import (
+    mend_pdb,
+    prepare_for_addHtaut,
+    add_tautomers,
+    identify_tit_sites,
+    rm_cys_bridges,
+    identify_cter,
+)
 from pdbmender.formats import get_chains_from_file
 from pege.constants import OHE_ATOMS_GRAPH, AA_HS
 
+
 def read_pdb_line(line: str) -> list:
     aname = line[12:16].strip()
     anumb = int(line[5:11].strip())
@@ -17,8 +25,10 @@ def read_pdb_line(line: str) -> list:
 
 
 def classify_atom(aname: str, resname: str) -> str:
-    if aname.startswith('H') and (resname in AA_HS and aname in AA_HS[resname]):
-        return 'H'
+    if aname.startswith("H") and (resname in AA_HS and aname in AA_HS[resname]):
+        return "H"
+    elif aname == "CA":
+        return "CA"
 
     if aname in ("N", "O"):
         if resname != "NTR":
@@ -36,10 +46,11 @@ def classify_atom(aname: str, resname: str) -> str:
     else:
         return f"{aname}_{resname}"
 
+
 def iter_f(fname):
     with open(fname) as f:
         for line in f:
-            if line.startswith('ATOM '):
+            if line.startswith("ATOM "):
                 yield line
 
 
@@ -51,30 +62,44 @@ def get_atom_info(fname):
         inscode = line[26]
         details = (chain, resnumb, resname, aname, inscode)
         original_atom_details[anumb] = details
-        
+
     original_atom_numbs = original_atom_details.keys()
     original_atom_infos = original_atom_details.values()
-    
+
     return original_atom_numbs, original_atom_infos
 
 
-def fix_structure(fname, chains_res, ff):
-    sysname = fname.split('.pdb')[0]
+def fix_structure(fname, ff):
+    sysname = fname
+    if ".pdb" in fname:
+        sysname = fname.split(".pdb")[0]
+    elif ".pqr" in fname:
+        sysname = fname.split(".pqr")[0]
+
     pdb_cleaned = f"{sysname}_cleaned.pdb"
     logfile_mend = "LOG_pdb2pqr"
-    mend_pdb(fname, pdb_cleaned, ff, ff, logfile=logfile_mend)
+    renumbered = mend_pdb(fname, pdb_cleaned, ff, ff, logfile=logfile_mend)
+
+    chains = get_chains_from_file(fname)
+    chains_res = identify_tit_sites(pdb_cleaned, chains, add_ser_thr=True)
 
     chains_res, cys_bridges = rm_cys_bridges(chains_res, logfile_mend)
 
-    old_ctrs = {chain: resnumb for chain, residues in chains_res.items() for resnumb, resname in residues.items() if resname == 'CTR'}
+    old_ctrs = {
+        chain: resnumb
+        for chain, residues in chains_res.items()
+        for resnumb, resname in residues.items()
+        if resname == "CTR"
+    }
     new_ctrs = identify_cter(pdb_cleaned, old_ctrs)
     for chain, resnumb in new_ctrs.items():
         chains_res[chain][str(resnumb)] = "CTR"
 
     output_pdb = f"{sysname}_final.pdb"
-    _, renumbered = add_tautomers(pdb_cleaned, chains_res, ff, output_pdb)
-    return output_pdb, chains_res, renumbered
+    _ = add_tautomers(pdb_cleaned, chains_res, ff, output_pdb)
 
+    os.system(f"rm {pdb_cleaned} LOG* removed.pqr addhtaut_cleaned.pdb")
+    return output_pdb, chains_res, renumbered
 
 
 def get_termini_info(fname, chains_res):
@@ -87,7 +112,6 @@ def get_termini_info(fname, chains_res):
             elif resname == "CTR" and not termini_resnumbs[chain][1]:
                 termini_resnumbs[chain][1] = resnumb
 
-
     termini_resnames = {chain: [None, None] for chain in chains_res.keys()}
     for line in iter_f(fname):
         aname, anumb, resname, chain, resnumb, x, y, z = read_pdb_line(line)
@@ -101,29 +125,29 @@ def get_termini_info(fname, chains_res):
 
 
 def pdb2feats(fname: str, save=True, ff="GROMOS") -> tuple:
-    chains = get_chains_from_file(fname)
-    chains_res = identify_tit_sites(fname, chains, add_ser_thr=True)
-
     original_atom_details = get_atom_info(fname)
 
-    output_pdb, chains_res, renumbered = fix_structure(fname, chains_res, ff)
+    output_pdb, chains_res, renumbered = fix_structure(fname, ff)
 
     termini_details = get_termini_info(fname, chains_res)
 
-    coords, feats, anumbs, details, aindices = encode_structure(output_pdb, termini_details, original_atom_details, renumbered)
+    coords, feats, anumbs, details, aindices = encode_structure(
+        output_pdb, termini_details, original_atom_details, renumbered
+    )
 
     if not save:
-        os.system(f'rm -f {output_pdb} *_cleaned.pdb* LOG* removed.pqr')
+        os.system(f"rm -f {output_pdb}")
 
     return coords, feats, anumbs, details, aindices
 
+
 def encode_structure(output_pdb, termini_details, original_atom_details, renumbered):
     termini_resnumbs, termini_resnames = termini_details
     original_atom_numbs, original_atom_infos = original_atom_details
-    
+
     coords, feats, anumbs, details = [], [], [], []
     aindices = {}
-    
+
     for line in iter_f(output_pdb):
         aname, anumb, resname, chain, resnumb, x, y, z = read_pdb_line(line)
 
@@ -135,20 +159,23 @@ def encode_structure(output_pdb, termini_details, original_atom_details, renumbe
             i_ter = termini_resnumbs[chain].index(resnumb)
             ter_type = "NTR" if i_ter == 0 else "CTR"
 
-            if ter_type == "NTR" and aname in ('N', 'H1', 'H2', 'H3'):
+            if ter_type == "NTR" and aname in ("N", "H1", "H2", "H3"):
                 resname = "NTR"
-            elif aname in ('O1', 'O2', 'HO11', 'HO21', 'HO12', 'HO22'):
+            elif aname in ("O1", "O2", "HO11", "HO21", "HO12", "HO22"):
                 resname = "CTR"
 
-        if aname[0] not in "NOS" and (resname not in AA_HS or aname not in AA_HS[resname]):
+        if (
+            aname[0] not in "NOS"
+            and (resname not in AA_HS or aname not in AA_HS[resname])
+        ) and aname != "CA":
             continue
-            
+
         res = classify_atom(aname, resname)
 
         if res in OHE_ATOMS_GRAPH:
             res_ohe = OHE_ATOMS_GRAPH.index(res)
 
-            ainfo = (chain, resnumb, resname, aname, ' ')
+            ainfo = (chain, resnumb, resname, aname, " ")
 
             coords.append((x, y, z))
             feats.append(res_ohe)
@@ -158,30 +185,31 @@ def encode_structure(output_pdb, termini_details, original_atom_details, renumbe
             if resnumb in renumbered.keys():
                 old_resnumb, inscode = renumbered[resnumb]
                 ainfo_search = (chain, old_resnumb, resname, aname, inscode)
-            elif resname in ('NTR', 'CTR'):
+            elif resname in ("NTR", "CTR"):
                 old_aname = aname
-                if resname == 'NTR':
+                if resname == "NTR":
                     old_resname = termini_resnames[chain][0]
-                elif resname == 'CTR':
-                    converted_atoms = {'O1': 'O', 'O2': 'OXT'}
+                elif resname == "CTR":
+                    converted_atoms = {"O1": "O", "O2": "OXT"}
                     if aname in converted_atoms:
                         old_aname = converted_atoms[aname]
                     old_resname = termini_resnames[chain][1]
-                ainfo_search = (chain, resnumb, old_resname, old_aname, ' ')
+                ainfo_search = (chain, resnumb, old_resname, old_aname, " ")
             else:
                 ainfo_search = ainfo
 
             if ainfo_search in original_atom_infos:
-                old_anumb = list(original_atom_numbs)[list(original_atom_infos).index(ainfo_search)]
+                old_anumb = list(original_atom_numbs)[
+                    list(original_atom_infos).index(ainfo_search)
+                ]
                 aindices[old_anumb] = len(anumbs) - 1
                 # print(f'{line.strip()}   {res:10}   {old_anumb}')
-            
-            elif res != 'H':
-                warning_msg = f'WARNING: atom {anumb} in {output_pdb} will be ignored'
-                print(warning_msg)
+
+            elif res != "H":
+                warning_msg = f"WARNING: atom {anumb} in {output_pdb} will be ignored"
+                print(warning_msg, line.strip())
 
     coords = torch.tensor(coords).reshape(1, -1, 3)
     feats = torch.tensor(feats).reshape(1, -1)
 
     return coords, feats, anumbs, details, aindices
-
